@@ -41,6 +41,7 @@ Usage:
     cfsp    [-c CFGFILE] [--version] [--help] [--username=<username>] [--password=<password>] [--project=<project>]
             [--image_id=<image_id>]...
             [--node_ip=<node_ip>]...
+            [--node_id=<node_id>]...
             [--image_file=<image_file>] [--sig_file=<sig_file>] [--pr_verify_rpt=<pr_verify_rpt] [--dont_verify_memory=<dont_verify_memory>]
             [--limit=<limit>] [--repeat=<repeat>]
             <command> [<args>...]
@@ -61,7 +62,8 @@ Options:
     --project=<password>        The user's project [default: project_example].
     
     --image_id=<image_id>       The id of the uploaded FPGA image, or NON_FPGA for a CPU VM node [default: NON_FPGA].
-    --node_ip=<node_ip>         The ip of the OpenVPN user's VM, e.g. a ZYC2 VM [default: 10.12.2.100].
+    --node_ip=<node_ip>         The ip of the user's VM, e.g. a ZYC2 VM.
+    --node_id=<node_id>         The id (rank) of either the VPN user's VM or FPGAs.
     
     --image_file=<image_file>      The FPGA image file to be uploaded [default: ./image.bit].
     --sig_file=<sig_file>          An FPGA bitstream signature file containing hashes from the build process.
